@@ -1,7 +1,3 @@
-library(tibble)
-library(dplyr)
-library(lubridate)
-
 # dthcaus_source ----
 ## Test 1: error on invalid mode ----
 test_that("dthcaus_source Test 1: error on invalid mode", {
@@ -17,14 +13,14 @@ test_that("dthcaus_source Test 1: error on invalid mode", {
 # derive_var_dthcaus ----
 ## Test 2: DTHCAUS is added from AE and DS ----
 test_that("derive_var_dthcaus Test 2: DTHCAUS is added from AE and DS", {
-  adsl <- tribble(
+  adsl <- tibble::tribble(
     ~STUDYID, ~USUBJID,
     "TEST01", "PAT01",
     "TEST01", "PAT02",
     "TEST01", "PAT03"
   )
 
-  ae <- tribble(
+  ae <- tibble::tribble(
     ~STUDYID, ~USUBJID, ~AESEQ, ~AEDECOD, ~AEOUT, ~AEDTHDTC,
     "TEST01", "PAT03", 12, "SUDDEN DEATH", "FATAL", "2021-04-04"
   ) %>%
@@ -32,7 +28,7 @@ test_that("derive_var_dthcaus Test 2: DTHCAUS is added from AE and DS", {
       AEDTHDT = ymd(AEDTHDTC)
     )
 
-  ds <- tribble(
+  ds <- tibble::tribble(
     ~STUDYID, ~USUBJID, ~DSSEQ, ~DSDECOD, ~DSTERM, ~DSSTDTC,
     "TEST01", "PAT01", 1, "INFORMED CONSENT OBTAINED", "INFORMED CONSENT OBTAINED", "2021-04-01",
     "TEST01", "PAT01", 2, "RANDOMIZATION", "RANDOMIZATION", "2021-04-11",
@@ -65,7 +61,7 @@ test_that("derive_var_dthcaus Test 2: DTHCAUS is added from AE and DS", {
     dthcaus = DSTERM
   )
 
-  expected_output <- tribble(
+  expected_output <- tibble::tribble(
     ~STUDYID, ~USUBJID, ~DTHCAUS,
     "TEST01", "PAT01", "DEATH DUE TO PROGRESSION OF DISEASE",
     "TEST01", "PAT02", NA,
@@ -83,13 +79,13 @@ test_that("derive_var_dthcaus Test 2: DTHCAUS is added from AE and DS", {
 
 ## Test 3: `dthcaus` handles symbols and string literals correctly ----
 test_that("derive_var_dthcaus Test 3: `dthcaus` handles symbols and string literals correctly", {
-  adsl <- tribble(
+  adsl <- tibble::tribble(
     ~STUDYID, ~USUBJID,
     "TEST01", "PAT01",
     "TEST01", "PAT02"
   )
 
-  ae <- tribble(
+  ae <- tibble::tribble(
     ~STUDYID, ~USUBJID, ~AESEQ, ~AEDECOD, ~AEOUT, ~AEDTHDTC,
     "TEST01", "PAT01", 12, "SUDDEN DEATH", "FATAL", "2021-04-04"
   ) %>%
@@ -97,7 +93,7 @@ test_that("derive_var_dthcaus Test 3: `dthcaus` handles symbols and string liter
       AEDTHDT = ymd(AEDTHDTC)
     )
 
-  ds <- tribble(
+  ds <- tibble::tribble(
     ~STUDYID, ~USUBJID, ~DSSEQ, ~DSDECOD, ~DSTERM, ~DSSTDTC,
     "TEST01", "PAT01", 1, "INFORMED CONSENT OBTAINED", "INFORMED CONSENT OBTAINED", "2021-04-02",
     "TEST01", "PAT01", 2, "RANDOMIZATION", "RANDOMIZATION", "2021-04-11",
@@ -127,7 +123,7 @@ test_that("derive_var_dthcaus Test 3: `dthcaus` handles symbols and string liter
     dthcaus = DSTERM
   )
 
-  expected_output <- tribble(
+  expected_output <- tibble::tribble(
     ~STUDYID, ~USUBJID, ~DTHCAUS,
     "TEST01", "PAT01", "Adverse Event",
     "TEST01", "PAT02", "DEATH DUE TO PROGRESSION OF DISEASE"
@@ -144,14 +140,14 @@ test_that("derive_var_dthcaus Test 3: `dthcaus` handles symbols and string liter
 
 ## Test 4: DTHCAUS and traceability vars are added from AE and DS ----
 test_that("derive_var_dthcaus Test 4: DTHCAUS and traceability vars are added from AE and DS", {
-  adsl <- tribble(
+  adsl <- tibble::tribble(
     ~STUDYID, ~USUBJID,
     "TEST01", "PAT01",
     "TEST01", "PAT02",
     "TEST01", "PAT03"
   )
 
-  ae <- tribble(
+  ae <- tibble::tribble(
     ~STUDYID, ~USUBJID, ~AESEQ, ~AEDECOD, ~AEOUT, ~AEDTHDTC,
     "TEST01", "PAT03", 12, "SUDDEN DEATH", "FATAL", "2021-04-04"
   ) %>%
@@ -159,7 +155,7 @@ test_that("derive_var_dthcaus Test 4: DTHCAUS and traceability vars are added fr
       AEDTHDT = ymd(AEDTHDTC)
     )
 
-  ds <- tribble(
+  ds <- tibble::tribble(
     ~STUDYID, ~USUBJID, ~DSSEQ, ~DSDECOD, ~DSTERM, ~DSSTDTC,
     "TEST01", "PAT01", 1, "INFORMED CONSENT OBTAINED", "INFORMED CONSENT OBTAINED", "2021-04-01",
     "TEST01", "PAT01", 2, "RANDOMIZATION", "RANDOMIZATION", "2021-04-11",
@@ -194,7 +190,7 @@ test_that("derive_var_dthcaus Test 4: DTHCAUS and traceability vars are added fr
     traceability_vars = vars(DTHDOM = "DS", DTHSEQ = DSSEQ)
   )
 
-  expected_output <- tribble(
+  expected_output <- tibble::tribble(
     ~STUDYID, ~USUBJID, ~DTHCAUS, ~DTHDOM, ~DTHSEQ,
     "TEST01", "PAT01", "DEATH DUE TO PROGRESSION OF DISEASE", "DS", 4,
     "TEST01", "PAT02", NA, NA, NA,
@@ -212,14 +208,14 @@ test_that("derive_var_dthcaus Test 4: DTHCAUS and traceability vars are added fr
 
 ## Test 5: DTHCAUS/traceabiity are added from 2 input datasets ----
 test_that("derive_var_dthcaus Test 5: DTHCAUS/traceabiity are added from 2 input datasets", {
-  adsl <- tribble(
+  adsl <- tibble::tribble(
     ~STUDYID, ~USUBJID,
     "TEST01", "PAT01",
     "TEST01", "PAT02",
     "TEST01", "PAT03"
   )
 
-  ae <- tribble(
+  ae <- tibble::tribble(
     ~STUDYID, ~USUBJID, ~AESEQ, ~AEDECOD, ~AEOUT, ~AEDTHDTC,
     "TEST01", "PAT01", 14, "SUDDEN DEATH", "FATAL", "2021-04-04",
     "TEST01", "PAT03", 12, "SUDDEN DEATH", "FATAL", "2021-04-04"
@@ -228,7 +224,7 @@ test_that("derive_var_dthcaus Test 5: DTHCAUS/traceabiity are added from 2 input
       AEDTHDT = ymd(AEDTHDTC)
     )
 
-  ds <- tribble(
+  ds <- tibble::tribble(
     ~STUDYID, ~USUBJID, ~DSSEQ, ~DSDECOD, ~DSTERM, ~DSSTDTC,
     "TEST01", "PAT01", 1, "INFORMED CONSENT OBTAINED", "INFORMED CONSENT OBTAINED", "2021-04-01",
     "TEST01", "PAT01", 2, "RANDOMIZATION", "RANDOMIZATION", "2021-04-11",
@@ -263,7 +259,7 @@ test_that("derive_var_dthcaus Test 5: DTHCAUS/traceabiity are added from 2 input
     traceability_vars = vars(DTHDOM = "DS", DTHSEQ = DSSEQ)
   )
 
-  expected_output <- tribble(
+  expected_output <- tibble::tribble(
     ~STUDYID, ~USUBJID, ~DTHCAUS, ~DTHDOM, ~DTHSEQ,
     "TEST01", "PAT01", "DEATH DUE TO PROGRESSION OF DISEASE", "DS", 4,
     "TEST01", "PAT02", NA, NA, NA,
@@ -283,14 +279,14 @@ test_that("derive_var_dthcaus Test 5: DTHCAUS/traceabiity are added from 2 input
 test_that("derive_var_dthcaus Test 6: DTHCAUS is added from AE and DS if filter is not specified", {
   # test based on covr report - the case for unspecified filter has not been tested
 
-  adsl <- tribble(
+  adsl <- tibble::tribble(
     ~STUDYID, ~USUBJID,
     "TEST01", "PAT01",
     "TEST01", "PAT02",
     "TEST01", "PAT03"
   )
 
-  ae <- tribble(
+  ae <- tibble::tribble(
     ~STUDYID, ~USUBJID, ~AESEQ, ~AEDECOD, ~AEOUT, ~AEDTHDTC,
     "TEST01", "PAT03", 12, "SUDDEN DEATH", "FATAL", "2021-04-04"
   ) %>%
@@ -298,7 +294,7 @@ test_that("derive_var_dthcaus Test 6: DTHCAUS is added from AE and DS if filter
       AEDTHDT = ymd(AEDTHDTC)
     )
 
-  ds <- tribble(
+  ds <- tibble::tribble(
     ~STUDYID, ~USUBJID, ~DSSEQ, ~DSDECOD, ~DSTERM, ~DSSTDTC,
     "TEST01", "PAT01", 1, "INFORMED CONSENT OBTAINED", "INFORMED CONSENT OBTAINED", "2021-04-01",
     "TEST01", "PAT01", 2, "RANDOMIZATION", "RANDOMIZATION", "2021-04-11",
@@ -331,7 +327,7 @@ test_that("derive_var_dthcaus Test 6: DTHCAUS is added from AE and DS if filter
     dthcaus = DSTERM
   )
 
-  expected_output <- tribble(
+  expected_output <- tibble::tribble(
     ~STUDYID, ~USUBJID, ~DTHCAUS,
     "TEST01", "PAT01", "INFORMED CONSENT OBTAINED",
     "TEST01", "PAT02", "INFORMED CONSENT OBTAINED",
