@@ -1,7 +1,4 @@
-library(tibble)
-library(dplyr)
-library(lubridate)
-input_ae <- tribble(
+input_ae <- tibble::tribble(
   ~STUDYID,   ~USUBJID,   ~AESEQ, ~AESTDTC,
   "my_study", "subject1",      1, "2020-01-02",
   "my_study", "subject1",      2, "2020-08-31",
@@ -15,7 +12,7 @@ input_ae <- tribble(
     AESTDT = ymd(AESTDTC)
   )
 
-input_ex <- tribble(
+input_ex <- tibble::tribble(
   ~STUDYID,   ~USUBJID,   ~EXSTDTC,     ~EXENDTC,    ~EXSEQ, ~EXDOSE, ~EXTRT,
   "my_study", "subject1", "2020-01-01", "2020-01-01",     1,      10, "treatment",
   "my_study", "subject1", "2020-08-29", "2020-08-29",     2,      10, "treatment",
@@ -58,7 +55,7 @@ test_that("derive_vars_last_dose Test 1: function works as expected", {
 test_that("derive_vars_last_dose Test 2: function checks validity of start and end dose inputs", {
   input_ex_wrong <- bind_rows(
     input_ex,
-    tribble(
+    tibble::tribble(
       ~STUDYID, ~USUBJID, ~EXSTDTC, ~EXENDTC, ~EXSEQ, ~EXDOSE, ~EXTRT,
       "my_study", "subject4", "2020-11-05", "2020-11-06", 1, 10, "treatment"
     ) %>%
@@ -117,7 +114,7 @@ test_that("derive_vars_last_dose Test 3: function returns traceability vars", {
 test_that("derive_vars_last_dose Test 4: function errors when multiple doses are on same date", {
   input_ex_dup <- bind_rows(
     input_ex,
-    tribble(
+    tibble::tribble(
       ~STUDYID, ~USUBJID, ~EXSTDTC, ~EXENDTC, ~EXSEQ, ~EXDOSE, ~EXTRT,
       "my_study", "subject2", "2020-01-20", "2020-01-20", 3, 0, "placebo"
     ) %>%
@@ -157,7 +154,7 @@ test_that("derive_vars_last_dose Test 4: function errors when multiple doses are
 test_that("derive_vars_last_dose Test 5: multiple doses on same date - dose_id supplied", {
   input_ex_dup <- bind_rows(
     input_ex,
-    tribble(
+    tibble::tribble(
       ~STUDYID, ~USUBJID, ~EXSTDTC, ~EXENDTC, ~EXSEQ, ~EXDOSE, ~EXTRT,
       "my_study", "subject2", "2020-01-20", "2020-01-20", 3, 0, "placebo"
     ) %>% mutate(
@@ -193,7 +190,7 @@ test_that("derive_vars_last_dose Test 5: multiple doses on same date - dose_id s
 
 ## Test 6: error is issued if same variable is found in both input datasets ----
 test_that("derive_vars_last_dose Test 6: error is issued if same variable is found in both input datasets", { # nolint
-  input_ae <- tribble(
+  input_ae <- tibble::tribble(
     ~STUDYID,   ~USUBJID,   ~AESEQ, ~EXSTDTC,
     "my_study", "subject1",      1, "2020-01-02",
     "my_study", "subject1",      2, "2020-08-31",
@@ -207,7 +204,7 @@ test_that("derive_vars_last_dose Test 6: error is issued if same variable is fou
       EXSTDT = ymd(EXSTDTC)
     )
 
-  input_ex <- tribble(
+  input_ex <- tibble::tribble(
     ~STUDYID, ~USUBJID, ~EXSTDTC, ~EXENDTC, ~EXSEQ, ~EXDOSE, ~EXTRT,
     "my_study", "subject1", "2020-01-01", "2020-01-01", 1, 10, "treatment",
     "my_study", "subject1", "2020-08-29", "2020-08-29", 2, 10, "treatment",
@@ -241,14 +238,14 @@ test_that("derive_vars_last_dose Test 6: error is issued if same variable is fou
 
 ## Test 7: no error is raised when setting `dose_date` to a renamed variable ----
 test_that("derive_vars_last_dose Test 7: no error is raised when setting `dose_date` to a renamed variable", { # nolint
-  adae <- tribble(
+  adae <- tibble::tribble(
     ~USUBJID, ~AESTDTC, ~AENDTC, ~ASTDT, ~AENDT, ~AEDECOD,
     "P01", "2022-01-10", "2022-01-12", ymd("2022-01-10"), ymd("2022-01-12"), "Nausea",
     "P02", "2022-01-31", "2022-01-31", ymd("2022-01-31"), ymd("2022-01-31"), "Vomitting",
     "P02", "2022-02-02", "2022-02-04", ymd("2022-02-02"), ymd("2022-02-04"), "Vomitting"
   )
 
-  adex <- tribble(
+  adex <- tibble::tribble(
     ~USUBJID, ~EXTRT, ~EXDOSFRQ, ~EXSTDTC, ~EXENDTC, ~ASTDT, ~AENDT, ~ASTDTM, ~AENDTM,
     "P01", "Drug A", "QD", "2022-01-09", "2022-01-12", ymd("2022-01-09"), ymd("2022-01-12"),
     ymd_hms("2022-01-09 09:30:00"), ymd_hms("2022-01-12 09:30:00"),
